;; Generated package description from keymap-popup.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "keymap-popup" "0.4.1.0.20260806.6" "Described keymaps with popup help" '((emacs "29.1")) :commit "16bd73e754ede80a7949afa37e3baedbf7820b61" :authors '(("Thanos Apollo" . "public@thanosapollo.org")) :maintainer '("Thanos Apollo" . "public@thanosapollo.org") :keywords '("convenience") :url "https://git.thanosapollo.org/emacs-keymap-popup/")
